@@ -10,7 +10,7 @@ use warnings;
 use Carp;
 
 use 5.6.1;               # 'our' was introduced in perl 5.6
-use version; our $VERSION = qv('0.0.4');
+use version; our $VERSION = qv('0.0.5');
 
 ## look in Games::Ratings for methods not provide by this package
 use base qw ( Games::Ratings );
@@ -204,7 +204,9 @@ sub _get_rating_difference_matching_percentage_score {
     ## lookup $D (rating difference) from lookup table
     my $D;
     if ($P lt 0.5) {
-        $D = -($reverse_scoring_probability_lookup_table{1-$P});
+        ## percentage score negated -- so we can use our lookup table
+        my $P_negated = sprintf("%.2f", 1-$P);
+        $D = -($reverse_scoring_probability_lookup_table{$P_negated});
     }
     else {
         $D = $reverse_scoring_probability_lookup_table{$P};
@@ -564,7 +566,7 @@ the FIDE rating system (esp. point 10.0).
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2008, Christian Bartolomaeus C<< <bartolin@gmx.de> >>. All rights reserved.
+Copyright (c) 2010, Christian Bartolomaeus C<< <bartolin@gmx.de> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
